@@ -139,6 +139,22 @@ def _visc(T, **kw):
     return v  # in cPoise
 
 
+def massweight(ci, qq, Ri):
+    # transform intensity weight to mass/volume weight
+    mw = ci * Ri ** 3 * qq ** 6 / (np.sin(qq * Ri) - qq * Ri * np.cos(qq * Ri)) ** 2
+    # norm = np.trapz(mw, Ri)
+    norm = mw.sum()
+    return mw/norm
+
+
+def numberweight(ci, qq, Ri):
+    # transform intensity weight to number weight
+    nw = ci * qq ** 6 / (np.sin(qq * Ri) - qq * Ri * np.cos(qq * Ri)) ** 2
+    # norm = np.trapz(nw, Ri)
+    norm = nw.sum()
+    return nw/norm
+
+
 def contin(datalist, Ngrid=256, tmin=-2, tmax=-2, bgr=0, distribution='dls', RDG=-1, timescale=1e-6, **kw):
     r"""
     Inverse Laplace transform known as CONTIN analysis developed by Steven Provencher [1,2]_ .
@@ -252,8 +268,12 @@ def contin(datalist, Ngrid=256, tmin=-2, tmax=-2, bgr=0, distribution='dls', RDG
          - .contin_alphalist             list of ALPHA in fits
 
         bestFit dataArray with best solution distribution content
-         - .contin_bestFit contains  [relaxation times,intensity weight ci, errors, hydrodynamic radii,
-                                       mass weight ci , number weight ci]
+         - .contin_bestFit contains
+              [*relaxationtimes, intensityweightci, errors, hydrodynamicradii, massweightci, numberweightci*]
+           Weighted ci are normalized that the *sum* over all points is equal 1.
+           The correponding probability is the probability of the intervall around the corresponding
+           relaxation time or Rh. Remember that because of the log scale the interval change width.
+
          - .contin_bestFit.attr()      shows all available parameters from CONTIN fit and other parameters
          - .contin_bestFit.fitquality  measure for the fit quality ALPHA and ...
          - .contin_bestFit.peaks       original CONTIN results as intensity weight relaxation time distribution
@@ -293,8 +313,9 @@ def contin(datalist, Ngrid=256, tmin=-2, tmax=-2, bgr=0, distribution='dls', RDG
      gfortran contin.f -o contin
      # move to a place in your PATH that this module can find it
 
-    If Peaks seem small please integrate them as the peak area determines the contributed intensity.
-    Peak area is strongly dependent on the peak point separation P(i)*(x[i]-x[i-1]) in particular on a log scale.
+    If Peaks seem small please integrate them as the peak area determines the contributed intensity (see last example).
+    Peak area is strongly dependent on the peak point separation dxi = (x[i]-x[i-1]) in particular on a log scale.
+    This weight is in some plots added to the probability as Pi*dxi resulting in equal height.
     See [4]_ for details.
     ::
 
@@ -308,10 +329,13 @@ def contin(datalist, Ngrid=256, tmin=-2, tmax=-2, bgr=0, distribution='dls', RDG
     This contribution is not caused by polydispersity and always present dependent on noise level.
 
     D = 0.05 nm²/ns corresponds to a hydrodynamic radius of 4.3 nm and results in a
-    relaxation time :math:`\Gamma= q^2D \approx 90.2 µs`.
+    relaxation time :math:`\Gamma= q^2D \approx 90.2 \mu s`.
 
-    The below plot shows the CONTIN result as correlation time distribution
-    with mean 92 µs ±17 µs and peak weight 95% in good approximation.
+     - The below plots shows the CONTIN result as correlation time distribution
+       with mean 92 µs ±17 µs and peak weight 95% in good approximation.
+     - The second plot shows the radius distrubution for different weights.
+       Probabilities are for an interval around a point x value that the sum of all points is normalized.
+       (not the integral on the log scale).
 
     ::
 
@@ -331,16 +355,27 @@ def contin(datalist, Ngrid=256, tmin=-2, tmax=-2, bgr=0, distribution='dls', RDG
      # do CONTIN
      dr=js.dls.contin(data,distribution='x')
      js.dls.contin_display(dr)         # display overview
-     # same but do it yourself
-     # plot results
-     p=js.grace(1.4,1)
-     p.plot(data,sy=[1,1,1],legend='simulated data')
-     p.xaxis(scale='log',label=r'\xG\f{} / µs',min=1,max=1e5)
-     p.yaxis(label=r'G\s1\N / P(\xG\f{})')
-     p.plot(dr,li=[1,3,3],sy=0,le='contin')
-     p.plot(dr.contin_bestFit[0].X,dr.contin_bestFit[0].Y*100,sy=2,le='distribution')
-     p.legend()
+
+     # same to demonstrate access to distributions
+     # plot first result in dr list
+     bf =dr[0].contin_bestFit
+     p=js.grace(1.,1.3)
+     p.multi(2,1)
+     p[0].plot(data,sy=[1,1,1],legend='simulated data')
+     p[0].xaxis(scale='log',label=r'\xG\f{} / µs',min=1,max=1e5)
+     p[0].yaxis(label=r'G\s1\N / P(\xG\f{})')
+     p[0].plot(dr[0],li=[1,3,3],sy=0,le='contin result')
+     p[0].plot(bf.X,bf.Y*10,sy=[2,0.5,2],le='relaxation time distribution')
+     p[0].legend(x=300,y=0.7)
+     p[1].plot(bf[3],bf[1],sy=[2,0.5,2],li=[1,1,''],le='intensity weight')
+     p[1].plot(bf[3],bf[4],sy=[2,0.5,3],li=[1,1,''],le='mass weight')
+     p[1].plot(bf[3],bf[5],sy=[2,0.5,4],li=[1,1,''],le='number weight')
+     p[1].xaxis(scale='log',label=r'R\sh\N / cm',min=1e-7,max=1e-5)
+     p[1].yaxis(label=r'P(R\sh\N)')
+     p[1].legend(x=1.5e-6,y=0.08)
+     p[1].text(f'Rh from contin {bf.ipeaks[0,6]:.2g}',x=1.3e-6,y=0.04)
      # p.save(js.examples.imagepath+'/contin.jpg')
+
      # access peak values by
      dr[0].contin_bestFit.ipeaks_name
      dr[0].contin_bestFit.ipeaks
@@ -352,10 +387,67 @@ def contin(datalist, Ngrid=256, tmin=-2, tmax=-2, bgr=0, distribution='dls', RDG
      :width: 50 %
      :alt: sphere
 
+    **Bimodal distribution** and the suppression of larger aggregates in mass and number weight.
+    The two particles sizes with a factor of 20 in radius shows same contribution to the scattering.
+    For mass or number weight the dependence of the scattering intensity on :math:`R^6`
+    compensates the contribution of larger aggregates.
+
+    The area under both intensity weighted peaks is equal as can be shown by integration.
+    ::
+
+     import jscatter as js
+     import numpy as np
+     t=js.loglist(0.125,10000,1000)   #times in microseconds
+     q=4*np.pi/1.333/632*np.sin(np.pi/2) # 90 degrees for 632 nm , unit is 1/nm**2
+     D=0.05*1000  # nm**2/ns * 1000 = units nm**2/microseconds
+     noise=0.0001  # typical < 1e-3
+     data=js.dA(np.c_[t,0.45*np.exp(-q**2*D*t)+0.45*np.exp(-q**2*D*20*t) +noise*np.random.randn(len(t))].T)
+
+     # add attributes to overwrite defaults
+     data.Angle      =90    # scattering angle in degrees
+     data.Temperature=293   # Temperature of measurement  in K
+     data.Viscosity  =1     # viscosity cPoise
+     data.Refractive =1.333 # refractive index
+     data.Wavelength =632   # wavelength
+     # do CONTIN
+     dr=js.dls.contin(data,distribution='x')
+
+     # same to demonstrate access to distributions
+     # plot first result in dr list
+     bf =dr[0].contin_bestFit
+     p=js.grace(1.,1.3)
+     p.multi(2,1)
+     p[0].plot(data,sy=[1,1,1],legend='simulated data')
+     p[0].xaxis(scale='log',label=r'\xG\f{} / µs',min=1,max=1e5)
+     p[0].yaxis(label=r'G\s1\N / P(\xG\f{})')
+     p[0].plot(dr[0],li=[1,3,3],sy=0,le='contin result')
+     p[0].plot(bf.X,bf.Y*10,sy=[2,0.5,2],le='relaxation time distribution')
+     p[0].legend(x=100,y=0.7)
+     p[1].plot(bf[3],bf[1],sy=[2,0.5,2],li=[1,1,''],le='intensity weight')
+     p[1].plot(bf[3],bf[4],sy=[2,0.5,3],li=[1,1,''],le='mass weight')
+     p[1].plot(bf[3],bf[5],sy=[2,0.5,4],li=[1,1,''],le='number weight')
+     p[1].xaxis(scale='log',label=r'R\sh\N / cm',min=1e-9,max=1e-5)
+     p[1].yaxis(label=r'P(R\sh\N)')
+     p[1].legend(x=1.5e-7,y=0.08)
+     p[1].text(f'Rh from contin {bf.ipeaks[0,6]:.3g}',x=1.3e-7,y=0.04)
+     # p.save(js.examples.imagepath+'/contin_bimodal.jpg')
+
+     # Peak integration resulting in about 0.5 for both
+     p1=(1<bf.X) &(bf.X<20) # peak borders 10 and 100
+     fp1=np.trapz(bf.Y[p1],bf.X[p1])/np.trapz(ff.Y,ff.X) #
+     p2=(40<ff.X) &(ff.X<400) # peak borders 10 and 100
+     fp2=np.trapz(ff.Y[p2],ff.X[p2])/np.trapz(ff.Y,ff.X) #
+
+
+    .. image:: ../../examples/images/contin_bimodal.jpg
+     :align: center
+     :width: 50 %
+     :alt: sphere
+
+
+
     R20 (scattering vector) is calculated as R20= 4e-7*pi*R15/R16*sin(R17/2), if R16!=0. else R20=0
 
-
-
     References
     ----------
     .. [1] CONTIN: A general purpose constrained regularization program for inverting
@@ -506,10 +598,7 @@ def contin(datalist, Ngrid=256, tmin=-2, tmax=-2, bgr=0, distribution='dls', RDG
     qq = lambda n, ll, theta: 4. * pi * n / (ll * 1e-7) * np.sin(np.deg2rad(theta) / 2.)
     # hydrodynamic radius  Rh(relaxationtime) in cm, gamma is relaxation time visc in cPoise
     Rh = lambda gamma, q, T, visc: kb * T / (pi * 0.06 * visc) * q ** 2 * gamma
-    # mass_weight(t)
-    massweight = lambda ci, qq, Ri: ci * Ri ** 3 * qq ** 6 / (np.sin(qq * Ri) - qq * Ri * np.cos(qq * Ri)) ** 2
-    # number weight
-    numberweight = lambda ci, qq, Ri: ci * qq ** 6 / (np.sin(qq * Ri) - qq * Ri * np.cos(qq * Ri)) ** 2
+
     ##########################################################
 
     # DEFINES THE kind of the distribution kernel
@@ -802,13 +891,17 @@ def contin(datalist, Ngrid=256, tmin=-2, tmax=-2, bgr=0, distribution='dls', RDG
             temp = np.r_[[[float(vv) for vv in line[:31].replace('D', 'E').split()] for line in chosen[6:Ngrid + 6]]].T
             # fit quality in 3rd line of chosen last chosen block
             try:
-                RR = Rh(temp[2] * timescale, contin_wavevector, T,
-                        v)  # hydrodynamic radius temp[2] is correlation time]
-                ci_massw = massweight(temp[0], contin_wavevector,
-                                      RR)  # mass weighted contribution ci  temp[0] is fraction
-                ci_numw = numberweight(temp[0], contin_wavevector, RR)  # number weighted contribution
-                # tohave [t,y,error_y] and hydrodyn Radius,  mass weight and number weighting the result output
-                data.contin_fits.append(dA(np.c_[temp[[2, 0, 1]].T, RR, ci_massw, ci_numw].T))
+                # hydrodynamic radius temp[2] is correlation time]
+                RR = Rh(temp[2] * timescale, contin_wavevector, T, v)
+                # intensity weight
+                ci_intw = temp[0]/temp[0].sum()
+                ci_intwerr = temp[1]/temp[0].sum()
+                # mass weighted contribution ci  temp[0] is fraction
+                ci_massw = massweight(temp[0], contin_wavevector, RR)
+                # number weighted contribution
+                ci_numw = numberweight(temp[0], contin_wavevector, RR)
+                # the result output as [t, y, error_y, hydrodyn Radius,  mass weight, number weight]
+                data.contin_fits.append(dA(np.c_[temp[2],ci_intw, ci_intwerr , RR, ci_massw, ci_numw].T))
             except:
                 data.contin_fits.append(dA(np.c_[temp[[2, 0, 1]].T].T))
 
