@@ -729,7 +729,6 @@ class lattice(object):
         ax.set_xlabel('x axis')
         ax.set_ylabel('y axis')
         ax.set_zlabel('z axis')
-        # ax.set_aspect("equal")
         xyzmin = self.XYZ.min()
         xyzmax = self.XYZ.max()
         ax.set_xlim(xyzmin, xyzmax)
@@ -1129,7 +1128,7 @@ class rhombicLattice(lattice):
 
         Returns
         -------
-            3x list of [unique q values, structure factor fhkl(q)**2, multiplicity mhkl(q)]
+            list of [unique q values, structure factor fhkl(q)**2, multiplicity mhkl(q), hkl indices]
 
         """
         qxyzb = self.getReciprocalLattice(size)[::-1]  # last to get later positive hkl list
@@ -1280,7 +1279,7 @@ class rhombicLattice(lattice):
                 return plane
         else:
             angle = np.arccos(np.clip(np.dot(vhkl / la.norm(vhkl), v3 / la.norm(v3)), -1.0, 1.0))
-            R = formel.rotationMatrix(rotvector, -angle)
+            R = formel.rotationMatrix(rotvector, angle)
             print(angle,rotvector)
             if plane is None:
                 return R
@@ -1383,7 +1382,7 @@ class rhombicLattice(lattice):
 
         rotvector = np.cross(vhkl, vv)
         angle = np.arccos(np.clip(np.dot(vhkl, vv), -1.0, 1.0))
-        R = formel.rotationMatrix(rotvector, -angle)
+        R = formel.rotationMatrix(rotvector, angle)
         self.rotatebyMatrix(R)
 
     def rotateAroundhkl(self, hkl, angle=None, vector=None, hkl2=None):
@@ -1457,7 +1456,7 @@ class rhombicLattice(lattice):
 
         """
         # test if it is rotation matrix
-        if not (np.allclose(la.det(R),1) and np.allclose(R @ R.T, np.eye(3))):
+        if not (np.allclose(la.det(R), 1) and np.allclose(R @ R.T, np.eye(3))):
             raise TypeError('R is not a rotation matrix.')
         else:
             # rotate points
@@ -1952,7 +1951,7 @@ class latticeFromCIF(rhombicLattice):
         ----------
         structure : str, pymatgen.structure
             Filename of the CIF file or structure read by pymatgen as
-            :code:`structure = pymatgen.Structure.from_file(js.examples.datapath+'/1011053.cif')`
+            :code:`structure = pymatgen.core.Structure.from_file(js.examples.datapath+'/1011053.cif')`
         typ : 'xray','neutron'
             scattering length for coherent xray or neutron scattering.
         size : 3x int
@@ -1960,19 +1959,18 @@ class latticeFromCIF(rhombicLattice):
 
         Notes
         -----
-        - If Bragg peaks or reciprocal lattice points are missing try to increase the size parameter
-          as these points might belong to higher order lattice planes.
-          E.g. for SiC (silicon carbide) the second peak at :math:`2\theta=35.6^{\circ}` belongs to hkl = 006 or
-          the  8th order peak at :math:`2\theta=60.1^{\circ}` belongs to hkl = 108 .
-        - CIF files can be found in the
-          `Crystallography Open Database <http://www.crystallography.net/cod/>`_
         - Pymatgen (Python Materials Genomics) is a robust, open-source Python library for
           materials analysis [1]_. See `Pymatgen <https://pymatgen.org/index.html#>`_
           ::
 
            # Simply install by
            pip install pymatgen
+
+        - CIF files can be found in the
+          `Crystallography Open Database <http://www.crystallography.net/cod/>`_
+
         - Pymatgen allows site occupancy which is taken here into account as average scattering length per site.
+
         - Pymatgen allows reading of CIF files or to get directly a structure from
           `Materials Project <https://materialsproject.org/>`_
           or `Crystallography Open Database <http://www.crystallography.net/cod/>`_ .
@@ -1989,6 +1987,12 @@ class latticeFromCIF(rhombicLattice):
            # silicon
            si = cod.get_structure_by_id(9008566)
 
+        - If Bragg peaks or reciprocal lattice points are missing try to increase the size parameter
+          as these points might belong to higher order lattice planes.
+          E.g. for SiC (silicon carbide) the second peak at :math:`2\theta=35.6^{\circ}` belongs to hkl = 006 or
+          the  8th order peak at :math:`2\theta=60.1^{\circ}` belongs to hkl = 108 .
+
+
         Examples
         --------
         The example is for silicon carbide. Please compare to `Moissanite
@@ -1997,7 +2001,7 @@ class latticeFromCIF(rhombicLattice):
 
          import jscatter as js
          import pymatgen
-         siliconcarbide = pymatgen.Structure.from_file(js.examples.datapath+'/1011053.cif')
+         siliconcarbide = pymatgen.core.Structure.from_file(js.examples.datapath+'/1011053.cif')
          sic=js.sf.latticeFromCIF(siliconcarbide)
          sic.getScatteringAngle(wavelength=0.13141,size=13)
 
