@@ -159,32 +159,9 @@ def readpdh(pdhFileName):
     else:
         return pdhs
 
-
-def fitDarkCurrent(darkfile):
-    """
-    Fits dark current with 5th order polynom + cosine.
-
-    This is dangerous as the darkcurrent has a noise that is not random but depends on
-    used detector and count time.
-
-    """
-    dark = dA(darkfile, lines2parameter=[2, 3, 4])
-    darkp = dark.prune(0.01, 6.3, 100)
-    # modeldark=lambda x,a0,a1,a2,a3,a4,a5,b0,b1,b2: a0+a1*x+a2*x**2+a3*x**3+a4*x**4+a5*x**4  +  b0*np.cos(((x-b1)/b2))
-    modeldark = lambda x, a0, a1, a2, a3, a4, a5, b0, b1, b2: a0 + a1 * (x - b1) + a2 * (x - b1) ** 2 + a3 * (
-            x - b1) ** 3 + a4 * (x - b1) ** 4 + a5 * (x - b1) ** 5 + b0 * np.cos(((x - b1) / b2))
-    darkp.setlimit(a0=[2010, 2050], b2=[0, 10], b0=[0, 100], b1=[2, 4])
-    darkp.fit(modeldark,
-              {'a0': 2030, 'a1': 4.5, 'a2': 5.5, 'a3': -1, 'b0': 36, 'b1': 2.9, 'b2': 0.88},
-              {'a4': 0, 'a5': 0, },
-              mapNames={'x': 'X'})
-    newdark = darkp.modelValues(x=dark.X)
-    newdark.setattr(dark)
-    return newdark
-
-
 # smearing Functions  ####################################################################
 
+
 def _wBLength(beam):
     """
     Weight at beam length y due to detector integration width.
@@ -1665,6 +1642,7 @@ def waterXrayScattering(composition='h2o1', T=293, units='mol'):
 
 
 def _find_peak(beam, edge):
+    # search for peals around zero in Q scale
     imax = imin = beam.Y[beam.X < edge].argmax()
     transmission = beam.Y[imax - 2:imax + 3].mean()
     # search for minima around transmission peak
@@ -1675,49 +1653,67 @@ def _find_peak(beam, edge):
     return centerTransmissionPeak, transmission
 
 
-def transmissionCorrection(data, dark, emptybeam=None, edge=0.03, exposure=None):
+def transmissionCorrection(data, dark, emptybeam=None, edge=0.03, exposure=None, transmission=None, Izero=None):
     r"""
     Subtract dark current, find primary beam, get transmission count and normalize by transmission and exposure time.
     IN PLACE.
 
-    Only for measurements including the primary beam from a semitransparent beamstop as from SAXSpace.
-    The maximum of the primary beam peak after dark subtraction determines transmission counts.
-    For 2D images use sasImage.
-
+    For measurements including the primary beam from a semitransparent beamstop as from SAXSpace
+    or Ganesha with explicit given parameters.
+    The maximum of the primary beam peak after dark subtraction determines transmission counts for the first.
 
     Parameters
     ----------
     data : dataArray
-        A measurement from a SAXSpace instrument read by js.dA('filename.pdh',lines2parameter=[2,3,4])
-    dark : dataArray
+        A raw measurement
+         - From a SAXSpace instrument read by js.dA('filename.pdh',lines2parameter=[2,3,4]) including primary beam.
+         - From a SAXSpace measurement read as sasImage and averaged using image.lineAverage including primary beam
+           and background subtracted (use dark = None).
+         - Ganesha radial averaged data with additional parameters.
+         - For other data the missing parameters need to be given explicitly.
+    dark : dataArray, None
         Dark current measurement.
+        If None is `explicitly` given, dark is already subtracted.
+         - For SAXSpace measurements a dark measurements including dead pixel
+           (these are corrected doing the subtraction).
+         - For Ganesha a value around 0.1/3600s as for the detectors this value is noted in the datasheet.
+           The value should be for same time as the exposure time (0.1 for 3600 s exposure).
     emptybeam : dataArray, float, default=None
         Empty beam measurement to subtract from measurement.
-        - If it is a raw measurement (not transmission corrected) first *transmissionCorrection* is applied.
-          The transmission of emptybeam measurement is given in absolute units (counts/s)
-        - If float (as counts/s) this value is used as emptybeam primary beam intensity for calculation
-          of the actual sample transmission
+         - If it is a raw measurement (not transmission corrected) first *transmissionCorrection* is applied.
+           The transmission of emptybeam measurement is given in absolute units (counts/s)
+         - If float (as counts/s) this value is used as emptybeam primary beam intensity for calculation
+           of the actual sample transmission
     edge : float, default 0.03
         Wavevector value below beam stop edge. The primary beam is searched below this value.
-    exposure : float, default None
+    exposure : optional, float, default None
         Exposure time in unit 's'.
-        If not given the xml description at the end of the file is examined.
+        If not given explicit it is extracted from the data :
+         - For SAXSpace data the xml description at the end of the file is examined.
+         - For Ganesha data from ``.exposure_time[0]``
+    transmission : optional, float, None
+        Transmission of the data measurement.
+        If not given explicit it is extracted from the data :
+         - If primary beam is included (SAXSpace) from the peak height.
+         - From Ganesha data from entry ``.transmission_factor[0]``
+    Izero : float, None
+        Intensity primary beam for normalisation if different detector distances are used.
+         - For Ganesha measurements taken from ``.Izero[0]`` (in 1e6 counts/s).
+         - Ignored for SAXSpace Izero=1.
 
     Returns
     -------
         None, IN PLACE
          - Adds attributes *.centerTransmissionPeak*, *.centerTransmissionPeakMax* and *.transmission* as
-           relative transmission to primary beam for samples.
+           relative transmission to primary beam for samples for SAXSSpace.
          - If emptybeam is NOT given the transmission value is the maximum peak value in counts/s.
            The same is for evaluating the emptybeam measurement itself.
            To compare the treated emptybeam multiply with this maximum peak value.
 
     Notes
     -----
-    Files from SAXSpace instrument (.pdh) can be read by
-    ::
+    We return here the :math:`\big((\frac{I-I_{dark}}{T}-I_{b}T\big) /I_0/t_{exposure}`
 
-     js.dA('filename.pdh',lines2parameter=[2,3,4])
 
     **Correction**
 
@@ -1793,6 +1789,7 @@ def transmissionCorrection(data, dark, emptybeam=None, edge=0.03, exposure=None)
         print('data has .transmission. It was already corrected and is not changed.')
         return
 
+    # treat emptybeam to get transmission
     if emptybeam is None:
         EBtransmission = 1.
     elif isinstance(emptybeam, numbers.Number):
@@ -1803,36 +1800,65 @@ def transmissionCorrection(data, dark, emptybeam=None, edge=0.03, exposure=None)
         transmissionCorrection(emptybeam, dark, emptybeam=None, edge=edge, exposure=None)
         EBtransmission = emptybeam.transmission
 
-    if data.X.min() > 0:
-        raise Exception('data seem to have no transmission peak ')
-    if exposure is None:
-        addXMLParameter(data)
-    else:
+    # get exposure time
+    if isinstance(exposure, numbers.Number):
         data.Exposure = [exposure, 's']
+    elif hasattr(data, 'exposure_time'):
+        data.Exposure = [data.exposure_time[0], 's']
+    elif hasattr(data, 'Exposure'):
+        pass
+    else:
+        # SAXSpace from xml appended data
+        addXMLParameter(data)
     if not hasattr(data, 'Exposure'):
         raise Exception('No exposure time found or given.')
 
     # dark subtraction
-    data.Y -= dark.Y
-    try:
-        data.eY = (data.eY ** 2 + dark.eY ** 2) ** 0.5
-    except AttributeError:
-        pass
+    if dark is not None:
+        if isinstance(dark, numbers.Number):
+            # float e.g for Dectris with 0.1 counts/3600s according to datasheet.
+            data.Y -= dark
+        else:
+            # given data in dataArray
+            data.Y -= dark.Y
+            try:
+                data.eY = (data.eY ** 2 + dark.eY ** 2) ** 0.5
+            except AttributeError:
+                pass
 
-    # get transmission and peak
-    centerTransmissionPeak, peakmax = _find_peak(data, edge)
-    data.centerTransmissionPeak = centerTransmissionPeak
-    data.centerTransmissionPeakMax = peakmax/data.Exposure[0]
-    data.transmission = peakmax/data.Exposure[0]/EBtransmission
+    if isinstance(transmission, numbers.Number):
+        # explicit given
+        data.transmission = transmission
+    elif hasattr(data, 'transmission_factor'):
+        # Ganesha images
+        data.transmission = data.transmission_factor[0]
+    elif data.X.min() < 0:
+        # semitransparent beamstop(SAXSpace)
+        # try to get transmission and peak from primary beam,
+        centerTransmissionPeak, peakmax = _find_peak(data, edge)
+        data.centerTransmissionPeak = centerTransmissionPeak
+        data.centerTransmissionPeakMax = peakmax/data.Exposure[0]
+        data.transmission = peakmax/data.Exposure[0]/EBtransmission
+    else:
+        raise Exception('It was not possible to get a transmission. Maybe give explicit?')
+
+    if isinstance(Izero, numbers.Number):
+        pass
+    elif hasattr(data, 'Izero'):
+        # Ganesha images
+        Izero = data.Izero[0]/1e6
+    elif hasattr(data, 'centerTransmissionPeak'):
+        # is SAXSpace data without Izero
+        Izero = 1
 
     # normalize by exposure and transmission
-    data.Y = data.Y / data.Exposure[0] / data.transmission
-    data.eY = data.eY / data.Exposure[0] / data.transmission
+    data.Y = data.Y / data.Exposure[0] / data.transmission / Izero
+    data.eY = data.eY / data.Exposure[0] / data.transmission / Izero
 
     # scale and subtract emptybeam if given
     if emptybeam is not None:
         # subtract emptybeam
-        data.Y =  data.Y - (data.transmission * emptybeam.Y)
+        data.Y = data.Y - (data.transmission * emptybeam.Y)
         data.eY = (data.eY ** 2 + (data.transmission * emptybeam.eY) ** 2) ** 0.5
 
 
