@@ -304,7 +304,7 @@ class dataListTest(unittest.TestCase):
         self.assertEqual(diffm.miss[2], 2)
         self.assertEqual(diffm.miss[1], None)
         diffm.merge([5, 6], missing='drop')
-        self.assertEqual(diffm.miss[5][0], 8)
+        self.assertEqual(diffm.miss[5], 8)
         diffm[5].miss = 88
         diffm.merge([5, 6], missing='first')
         self.assertEqual(diffm.miss[5], 88)
